@@ -43,7 +43,7 @@ $lang = array_merge($lang, array(
 	'DEFAULT_LANGUAGE'				=> 'Standaardtaal',
 	'DEFAULT_STYLE'					=> 'Standaardstijl',
 	'DISABLE_BOARD'					=> 'Forum uitschakelen',
-	'DISABLE_BOARD_EXPLAIN'			=> 'Dit zal het forum onbereikbaar maken voor gebruikers. U kunt ook een kort (255 tekens) bericht laten weergeven als u dat wilt.',
+	'DISABLE_BOARD_EXPLAIN'			=> 'Dit zal het forum onbereikbaar maken voor gebruikers die geen beheerders of moderators zijn. U kunt ook een korte tekst van 255 tekens laten weergeven als u wenst.',
 	'OVERRIDE_STYLE'				=> 'Gebruikerstijl overschrijven',
 	'OVERRIDE_STYLE_EXPLAIN'		=> 'Vervangt de gebruiksstijl met de standaardstijl.',
 	'SITE_DESC'						=> 'Sitebeschrijving',
@@ -103,7 +103,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_GALLERY_PATH'			=> 'Avatar-galerijpad',
 	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Het pad onder uw phpBB-hoofddirectory voor vooringestelde afbeeldingen, bijvoorbeeld; <samp>images/avatars/gallery</samp>.',
 	'AVATAR_STORAGE_PATH'			=> 'Avatar-opslagpad',
-	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Het pad onder uw phpBB-hoofdirectory, bijvoorbeeld; <samp>images/avatars/upload</samp>.',
+	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Het pad onder uw phpBB-hoofddirectory bijvoorbeeld; <samp>images/avatars/upload</samp>. <br />Het uploaden van avatars <strong>zal niet beschikbaar zijn</strong> als deze map niet schrijfbaar is.',
 	'MAX_AVATAR_SIZE'				=> 'Maximale avatar-grootte',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Breedte x hoogte in pixels.',
 	'MAX_FILESIZE'					=> 'Maximale avatar-bestandsgrootte',
@@ -547,4 +547,4 @@ $lang = array_merge($lang, array(
 	'JAB_USERNAME_EXPLAIN'		=> 'Geef een geregistreerde gebruikersnaam of een geldige JID op. De gebruikersnaam zal niet worden gecontroleerd op geldigheid. Als u alleen een gebruikersnaam opgeeft dan zal uw JID de gebruikersnaam worden en de server die U hierboven heeft opgegeven. Anders voert u een geldig JID in, bijvoorbeeld : gebruiker@jabber.org.',
 ));
 
-?>
\ No newline at end of file
+?>
