@@ -49,7 +49,7 @@ $lang = array_merge($lang, array(
 	'ACP_BAN'					=> 'Verbanningen',
 	'ACP_BAN_EMAILS'			=> 'E-mailadressen verbannen',
 	'ACP_BAN_IPS'				=> 'IP-adressen verbannen',
-	'ACP_BAN_USERNAMES'			=> 'Gebruikersnamen verbannen',
+	'ACP_BAN_USERNAMES'			=> 'Gebruikers verbannen',
 	'ACP_BBCODES'				=> 'BBCodes',
 	'ACP_BOARD_CONFIGURATION'	=> 'Forumconfiguratie',
 	'ACP_BOARD_FEATURES'		=> 'Forumfunctionaliteiten',
@@ -748,4 +748,4 @@ $lang = array_merge($lang, array(
 	'LOG_WORD_EDIT'			=> '<strong>Woordcensuur gewijzigd</strong><br />» %s',
 ));
 
-?>
\ No newline at end of file
+?>
