@@ -87,9 +87,10 @@ $lang = array_merge($lang, array(
 	'AVATAR_PARTIAL_UPLOAD'			=> 'Het opgegeven bestand is maar gedeeltelijk geüpload.',
 	'AVATAR_PHP_SIZE_NA'			=> 'De bestandsgrootte van de avatar is te groot.<br />De maximale toegestaande bestandsgrootte die ingesteld is in php.ini kon niet worden vastgesteld.',
 	'AVATAR_PHP_SIZE_OVERRUN'		=> 'De bestandsgrootte van de avatar is te groot. De maximale toegestaande bestandsgrootte is %1$d %2$s.<br />Vergeet niet dat dit ingesteld is in php.ini en niet kan worden overschreden.',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'	=> 'De opgegeven avatar kon niet worden geupload doordat tijdens het verzoek een time-out is opgetreden.',
 	'AVATAR_URL_INVALID'			=> 'De opgegeven URL is ongeldig.',
 	'AVATAR_URL_NOT_FOUND'			=> 'Het opgegeven bestand kan niet worden gevonden.',
-	'AVATAR_WRONG_FILESIZE'			=> 'De bestandsgrootte van de avatar moet tussen de 0 en %1d %2s zijn.',
+	'AVATAR_WRONG_FILESIZE'			=> 'De bestandsgrootte van de avatar moet tussen de 0 en %1$d %2$s zijn.',
 	'AVATAR_WRONG_SIZE'				=> 'De opgegeven avatar is %5$d pixels breed en %6$d pixels hoog. Avatars moeten minstens %1$d pixels breed en %2$d pixels hoog zijn, maar mogen niet groter zijn dan %3$d pixels breed en %4$d pixels hoog.',
 
 	'BACK_TO_TOP'			=> 'Omhoog',
@@ -340,6 +341,9 @@ $lang = array_merge($lang, array(
 	'MODERATE'				=> 'Modereren',
 	'MODERATOR'				=> 'Moderator',
 	'MODERATORS'			=> 'Moderators',
+	'MODULE_NOT_ACCESS'		=> 'Module is niet toegankelijk.',
+	'MODULE_NOT_FIND'		=> 'Kan de module %s niet vinden.',
+	'MODULE_FILE_INCORRECT_CLASS'	=> 'Het modulebestand %s bevat niet de juiste class [%s]',
 	'MONTH'					=> 'Maand',
 	'MOVE'					=> 'Verplaatsen',
 	'MSNM'					=> 'MSNM/WLM',
@@ -416,9 +420,9 @@ $lang = array_merge($lang, array(
 	'OFFLINE'					=> 'Offline',
 	'ONLINE'					=> 'Online',
 	'ONLINE_BUDDIES'			=> 'Online vrienden',
-	'ONLINE_USERS_TOTAL'		=> 'Er zijn in totaal <strong>%d</strong> gebruikers online :: ',
-	'ONLINE_USERS_ZERO_TOTAL'	=> 'Er zijn in totaal <strong>0</strong> gebruikers online :: ',
-	'ONLINE_USER_TOTAL'			=> 'Er is in totaal <strong>1</strong> gebruiker online :: ',
+	'ONLINE_USERS_TOTAL'		=> 'Er zijn in totaal <strong>%d</strong> gebruikers online : ',
+	'ONLINE_USERS_ZERO_TOTAL'	=> 'Er zijn in totaal <strong>0</strong> gebruikers online : ',
+	'ONLINE_USER_TOTAL'			=> 'Er is in totaal <strong>%d</strong> gebruiker online : ',
 	'OPTIONS'					=> 'Opties',
 
 	'PAGE_OF'					=> 'Pagina <strong>%1$d</strong> van <strong>%2$d</strong>',
@@ -649,7 +653,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_USERS_ZERO'		=> 'Geregistreerde gebruikers: <strong>0</strong>',
 	'TRACKED_PHP_ERROR'		=> '%s gevonden PHP-fouten',
 
-	'UNABLE_GET_IMAGE_SIZE'		=> 'Het was onmogelijk om de afmeting van de afbeelding te bepalen.',
+	'UNABLE_GET_IMAGE_SIZE'		=> 'Het wat onmogelijk om de afmeting van de afbeelding te bepalen. Controleer of de URL die u heeft ingevoerd juist is.',
 	'UNABLE_TO_DELIVER_FILE'	=> 'Het bestand kan niet worden afgeleverd.',
 	'UNKNOWN_BROWSER'			=> 'Onbekende browser',
 	'UNMARK_ALL'				=> 'Alle markeringen verwijderen',
